*************************************************************
*************************************************************
** Replicate Monadic Treatment Comparison Analysis 
** Ahn, Esarey, and Scholz
** Reputation and Cooperation in Voluntary Exchanges
** November 20, 2008
*************************************************************
*************************************************************


****************************************************
* Load Data                                        *
****************************************************

use "merged monadic.dta", replace
set more off
gen panelid = 1000*sesidnum + subject
tsset panelid period
version 10


****************************************************
* Test Difference of Treatments: Cooperation Plays *
* (p. 14 of manuscript)                            *
****************************************************

**Averaged across all periods**
xi: reg percentc I.treatmnt, robust cluster(sesidnum)

**By Period**
bysort period: reg percentc  _Itreatmnt_1 _Itreatmnt_2, robust cluster(sesidnum)


****************************************************
* Test Difference of Treatments: # of CC Games     *
* (p. 14 of manuscript)                            *
****************************************************


**Averaged across all periods**
xi: poisson numbrfcc I.treatmnt coopertr period, cluster(sesidnum)

**By Period**
xi: poisson numbrfcc I.treatmnt coopertr if period==1, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==2, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==3, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==4, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==5, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==6, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==7, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==8, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==9, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==10, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==11, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==12, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==13, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==14, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==15, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==16, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==17, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==18, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==19, cluster(sesidnum)
mfx
xi: poisson numbrfcc I.treatmnt coopertr if period==20, cluster(sesidnum)


****************************************************
* Test Difference of Treatments: # of Games        *
* (p. 14 of manuscript)                            *
****************************************************

**Averaged across all periods**
xi: poisson links I.treatmnt period, cluster(sesidnum)

**By Period**
xi: poisson links I.treatmnt if period==1, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==2, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==3, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==4, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==5, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==6, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==7, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==8, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==9, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==10, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==11, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==12, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==13, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==14, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==15, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==16, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==17, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==18, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==19, cluster(sesidnum)
mfx
xi: poisson links I.treatmnt if period==20, cluster(sesidnum)
mfx

****************************************************
* Test Difference of Treatments: Earnings          *
* (p. 15 of manuscript)                            *
****************************************************

**Averaged across all periods**
xi: reg profit I.treatmnt, robust cluster(sesidnum)

**By period**
bysort period: reg profit  _Itreatmnt_1 _Itreatmnt_2, robust cluster(sesidnum)


****************************************************
* Load Data including Global Truthful Treatment    *
****************************************************

use "merged monadic with global truthful.dta", replace
set more off
gen panelid = 1000*sesidnum + subject
tsset panelid period



****************************************************
* Test Difference of Global Truthful Treatment:    *
* Avg. %C  (p. 23 of manuscript)                   *
****************************************************

xi: reg percentc I.treatmnt, robust cluster(sesidnum)
lincom _Itreatmnt_2-_Itreatmnt_3
lincom _Itreatmnt_1-_Itreatmnt_3

****************************************************
* Test Difference of Global Truthful Treatment:    *
* Avg. CC Links  (p. 23 of manuscript)             *
****************************************************

*first compute an average
xi: reg numbrfcc I.treatmnt, cluster(sesidnum)

*see if the difference is statistically significant in a poisson model
xi: poisson numbrfcc I.treatmnt coopertr period, cluster(sesidnum)
lincom _Itreatmnt_2-_Itreatmnt_3
lincom _Itreatmnt_1-_Itreatmnt_3



****************************************************
* Test Difference of Global Truthful Treatment:    *
* Avg. Earnings  (p. 23 of manuscript)             *
****************************************************

xi: reg profit I.treatmnt, robust cluster(sesidnum)
lincom _Itreatmnt_2-_Itreatmnt_3
lincom _Itreatmnt_1-_Itreatmnt_3




****************************************************
* Table 5 (p. 23 of manuscript)                    *
****************************************************


use "merged monadic with global truthful", replace
keep if(treatmnt==0)
mean links numbrfcc profit, over(sesidnum)
mean percentc, over(sesidnum)
mean links numbrfcc profit
mean percentc

use "merged monadic with global truthful", replace
keep if(treatmnt==1)
mean links numbrfcc profit, over(sesidnum)
mean percentc, over(sesidnum)
mean links numbrfcc profit
mean percentc

use "merged monadic with global truthful", replace
keep if(treatmnt==2)
mean links numbrfcc profit, over(sesidnum)
mean percentc, over(sesidnum)
mean links numbrfcc profit
mean percentc

use "merged monadic with global truthful", replace
keep if(treatmnt==3)
mean links numbrfcc profit, over(sesidnum)
mean percentc, over(sesidnum)
mean links numbrfcc profit
mean percentc



